==> pgmarket-1.3.1.tar.gz: pgmarket-1.3.1/shopping/index.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");

setdefault($id, 1);
$qid_c = get_sub_categories($id);
$qid_p = get_products($id);

$DOC_TITLE = $Shopping_Catalog;
$SESSION["goback"]["request_uri"] = $REQUEST_URI;
$SESSION["goback"]["query_string"] = $QUERY_STRING;
include("$CFG->templatedir"."header.ihtml");
include("templates/catalog.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function get_sub_categories($id=1) {
/* get the name and description of all the sub-categories under this one */

	$qid = db_query("SELECT id, name, on_special, description
			FROM categories
			WHERE parent_id = '$id' AND id > 1
			ORDER BY on_special, name
			");
	return $qid;
}

function get_products($category_id=1) {
/* get all the products under this category */

	$qid = db_query("
	SELECT
		 p.id
		,p.name
		,p.brand_id
		,p.price
		,p.iva_id
		,p.discount
		,p.discqty
		,p.weight
		,p.on_special
		,p.description
		,p.imagetype
		,p.imagewidth
		,p.imageheight
		,p.thumbwidth
		,p.thumbheight
		,pc.category_id
	FROM
		 products p
		,products_categories pc
	WHERE p.id = pc.product_id
		AND pc.category_id = '$category_id'
	ORDER BY p.on_special ASC
	");

	return $qid;
}

?>

==> pgmarket-1.3.2.tar.gz: pgmarket-1.3.2/shopping/index.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");

setdefault($id, 1);
$qid_c = get_sub_categories($id);
$qid_p = get_products($id);

$DOC_TITLE = $Shopping_Catalog;
$SESSION["goback"]["request_uri"] = $REQUEST_URI;
$SESSION["goback"]["query_string"] = $QUERY_STRING;
include("$CFG->templatedir"."header.ihtml");
include("templates/catalog.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function get_sub_categories($id=1) {
/* get the name and description of all the sub-categories under this one */

	$qid = db_query("SELECT id, name, on_special, description
			FROM categories
			WHERE parent_id = '$id' AND id > 1
			ORDER BY on_special, name
			");
	return $qid;
}

function get_products($category_id=1) {
/* get all the products under this category */

	$qid = db_query("
	SELECT
		 p.id
		,p.name
		,p.price
		,p.iva_id
		,p.discount
		,p.discqty
		,p.weight
		,p.on_special
		,p.description
		,p.imagetype
		,p.imagewidth
		,p.imageheight
		,p.thumbwidth
		,p.thumbheight
		,pc.category_id
		,b.name AS bname
	FROM products p JOIN products_categories pc ON (p.id = pc.product_id) JOIN brands b ON (p.brand_id = b.id)
	WHERE pc.category_id = '$category_id'
	ORDER BY p.on_special ASC
	");

	return $qid;
}

?>
